@@ -17,6 +17,8 @@
   auth_link (&auth_md5);		/* link in the md5 authenticator */
   auth_link (&auth_pla);		/* link in the pla authenticator */
   auth_link (&auth_log);		/* link in the log authenticator */
+  auth_link (&auth_bea);		/* link in the bea authenticator */
+  auth_link (&auth_oa2);		/* link in the oa2 authenticator */
   mail_versioncheck (CCLIENTVERSION);
   ssl_onceonlyinit ();
   mail_parameters (NIL,SET_DISABLEPLAINTEXT,(void *) 2);
