@@ -17,3 +17,6 @@ extern AUTHENTICATOR auth_ext;
 extern AUTHENTICATOR auth_md5;
 extern AUTHENTICATOR auth_pla;
 extern AUTHENTICATOR auth_log;
+extern AUTHENTICATOR auth_bea;
+extern AUTHENTICATOR auth_oa2;
+int pith_ssl_encryption_version(char *);
